# Windows Azure Storage library for Node.js
A simple implementation of Windows Azure Storage API for Node.js

# Installation
waz-storage-js depends on querystring (>= v0.0.1) and xml2js (>= v0.1.9).

To install via npm

	npm install waz-storage-js

# Examples

## Initial Setup

	var waz = waz.establishConnection({ 
			accountName: 'your_account_name'
			, accountKey: 'your_key', 
			, useSsl: false 
		  });

## Blobs

	// Creating a new container
	waz.blobs.container.create('myContainer', function(err, container){
	});
	
	// Listing existing containers
	waz.blobs.container.list(function(err, containers){
	});

	// Finding a container
	waz.blobs.container.find('myContainer', function(err, container){

			// Getting container's metadata
			container.metadata(function(err, metadata){
			});
			
			// Getting container's properties
			container.properties(function(err, properties){
			});

			// Adding metadata to a container
			container.putMetadata({'x-ms-custom' : 'MyValue'}, function(err){
			});
			
			// Getting container's ACL
			container.getAcl(function(err, acl){
			});
			
			// Setting container's ACL (null, 'blob', 'container')
			container.setAcl('container', function(err, container){
			});
			
			// Listing blobs in a container
			container.blobs(function(err, blobs){
			});
			
			// Getting blob's information
			result.getBlob('myfolder/my file.txt', function(err, blob){

				// Adding metadata to a blob
				blob.putMetadata({'x-ms-custom' : 'MyValue'}, function(err){
				});
								
				// Getting blob's metadata
				blob.metadata(function(err, metadata){
				});

				// Adding properties to a blob
				blob.putProperties({'x-ms-blob-property1': 'MyValue'}, function(err, properties){
				});
				
				// Getting blob's properties
				blob.properties(function(err, properties){
				});
				
				// Creating a snapshot of a blob
				blob.snapshot(function(err, blob){
					console.log(blob.snapshotDate);
				});
												
				// Getting blob's contents
				blob.getContents(function(err, data){
					
					blob.metadata = {'x-ms-custom-medatada': 'value'};
					blob.contentType = 'text/css';
					
					// Updating blob's contents
					blob.updateContents('new-content', function(err, blob){
						// Copying a blob
						blob.copy('container/newFolder/my file_copy.txt', function(err, newBlob){
						});					

						// Removing a blob
						blob.destroy(function(err){
						});
					});
				});
			});
						
			// Storing a new Blob
			result.store('folder/my file.xml', '<xml>content</xml>', 'text/xml', {'x-ms-MyProperty': 'value'}, function(err, result){
			});			
		}
	});
	
	// Deleting containers
	waz.blobs.container.delete('myContainer', function(err){
	});

## Queues
	Coming Soon - If you are anxious, you can always contribute with the project :)

## Tables
	Coming Soon - If you are anxious, you can always contribute with the project :)


# Remaining Stuff
* Documentation
* SharedAccessSignature

## Blobs
* Shared Access Signature
* Blocks

## Queues
* Everything

## Tables
* Everything

# Known Issues

* Container's putProperties doesn't work.

# Authors

* Juan Pablo Garcia ([jpgarcia](http://github.com/jpgarcia) | [@jpgd](http://www.twitter.com/jpgd))

# Contributors

* Johnny G. Halife ([johnnyhalife](http://github.com/johnnyhalife) | [@johnnyhalife](http://www.twitter.com/johnnyhalife))
* Ezequiel Julio Morito ([ezequielm](http://github.com/ezequielm) | [@ezequielm](http://www.twitter.com/ezequielm))

# License 

(The MIT License)

Copyright (c) 2010 by Juan Pablo Garcia Dalolla

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
'Software'), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
